/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_3b5Lb9kK);
  numBytes += sLine_init(&sLine_5pdRwlUq);
  numBytes += sLine_init(&sLine_l70MpCB8);
  numBytes += sLine_init(&sLine_0Xj2bOwj);
  numBytes += sLine_init(&sLine_uies1ql3);
  numBytes += sBiquad_init(&sBiquad_s_YaWOQuBW);
  numBytes += sLine_init(&sLine_4ssQJkHF);
  numBytes += sLine_init(&sLine_opJ0aZvt);
  numBytes += sLine_init(&sLine_FCx1jg80);
  numBytes += sLine_init(&sLine_wHT95bmE);
  numBytes += sBiquad_init(&sBiquad_s_SWmEBlcg);
  numBytes += sLine_init(&sLine_11sNIWlK);
  numBytes += sLine_init(&sLine_t75ki2MV);
  numBytes += sLine_init(&sLine_Zb6YUBu5);
  numBytes += sLine_init(&sLine_VEq3rhW4);
  numBytes += sLine_init(&sLine_76njA3SW);
  numBytes += sBiquad_init(&sBiquad_s_tsdo2Khx);
  numBytes += sLine_init(&sLine_WERGYbFl);
  numBytes += sLine_init(&sLine_uNxrLsaW);
  numBytes += sLine_init(&sLine_CGvrdPyX);
  numBytes += sLine_init(&sLine_DrdgR2fq);
  numBytes += sLine_init(&sLine_2mtPhHh7);
  numBytes += sBiquad_init(&sBiquad_s_p2ZsENeT);
  numBytes += sLine_init(&sLine_z6aFvI6m);
  numBytes += sLine_init(&sLine_CatRy2GN);
  numBytes += sLine_init(&sLine_3gychB78);
  numBytes += sLine_init(&sLine_r3Rtg0RV);
  numBytes += sBiquad_init(&sBiquad_s_smsBpBR8);
  numBytes += sLine_init(&sLine_82ySjFOQ);
  numBytes += sLine_init(&sLine_6q6xJfTA);
  numBytes += sLine_init(&sLine_z8h5v5iK);
  numBytes += sLine_init(&sLine_Sky1LdAi);
  numBytes += sLine_init(&sLine_1BDb66NM);
  numBytes += sBiquad_init(&sBiquad_s_9ovstBVP);
  numBytes += sLine_init(&sLine_q4iQCEwb);
  numBytes += sPhasor_k_init(&sPhasor_AuUBsHAE, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_Oic3g2ju);
  numBytes += sRPole_init(&sRPole_hLFhXDnd);
  numBytes += sRPole_init(&sRPole_6yJQjDNu);
  numBytes += sTabhead_init(&sTabhead_yZto2JCT, &hTable_aHAKQoE2);
  numBytes += sTabread_init(&sTabread_LMCaSiw2, &hTable_aHAKQoE2, false);
  numBytes += sTabread_init(&sTabread_jZzOrFQ1, &hTable_aHAKQoE2, false);
  numBytes += sLine_init(&sLine_HDsWzSeF);
  numBytes += sTabhead_init(&sTabhead_OEU966Tx, &hTable_jnZsI60y);
  numBytes += sTabread_init(&sTabread_7CTvnIy0, &hTable_jnZsI60y, false);
  numBytes += sTabread_init(&sTabread_OQEHgfQ1, &hTable_jnZsI60y, false);
  numBytes += sLine_init(&sLine_I1JjPUFG);
  numBytes += sTabwrite_init(&sTabwrite_zDkO9kqY, &hTable_jnZsI60y);
  numBytes += sTabwrite_init(&sTabwrite_sOKHXoyv, &hTable_aHAKQoE2);
  numBytes += sLine_init(&sLine_NMGiU4Ja);
  numBytes += sPhasor_k_init(&sPhasor_3VmzEI9f, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_KXTSOAx3);
  numBytes += sRPole_init(&sRPole_9tUCt1rG);
  numBytes += sRPole_init(&sRPole_4F4RJ45g);
  numBytes += sTabhead_init(&sTabhead_L1egLcQf, &hTable_ob9XAt1H);
  numBytes += sTabread_init(&sTabread_DThH8iIp, &hTable_ob9XAt1H, false);
  numBytes += sTabread_init(&sTabread_uOY2JMAB, &hTable_ob9XAt1H, false);
  numBytes += sLine_init(&sLine_jTyLFTYT);
  numBytes += sTabhead_init(&sTabhead_KVxCPjdt, &hTable_T3T3Uyfm);
  numBytes += sTabread_init(&sTabread_ngbsxazB, &hTable_T3T3Uyfm, false);
  numBytes += sTabread_init(&sTabread_guD2wAKC, &hTable_T3T3Uyfm, false);
  numBytes += sLine_init(&sLine_56nQiYn4);
  numBytes += sTabwrite_init(&sTabwrite_IBjTHYbx, &hTable_T3T3Uyfm);
  numBytes += sTabwrite_init(&sTabwrite_LSIxTiW1, &hTable_ob9XAt1H);
  numBytes += sLine_init(&sLine_ivwY06UJ);
  numBytes += sPhasor_k_init(&sPhasor_7wMWvrc2, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_6wXrpXjk);
  numBytes += sRPole_init(&sRPole_iqlvj3ix);
  numBytes += sRPole_init(&sRPole_74BK7t5B);
  numBytes += sTabhead_init(&sTabhead_YXN8xdBt, &hTable_WHfFeRML);
  numBytes += sTabread_init(&sTabread_sgdUqCFz, &hTable_WHfFeRML, false);
  numBytes += sTabread_init(&sTabread_iDT5GGTH, &hTable_WHfFeRML, false);
  numBytes += sLine_init(&sLine_LMeC5Dp0);
  numBytes += sTabhead_init(&sTabhead_kzjcmKgs, &hTable_nRN7JZHi);
  numBytes += sTabread_init(&sTabread_gKHK20YU, &hTable_nRN7JZHi, false);
  numBytes += sTabread_init(&sTabread_9uJPz5Jm, &hTable_nRN7JZHi, false);
  numBytes += sLine_init(&sLine_ukNAW7H6);
  numBytes += sTabwrite_init(&sTabwrite_J58SQrMi, &hTable_nRN7JZHi);
  numBytes += sTabwrite_init(&sTabwrite_EUOScsc5, &hTable_WHfFeRML);
  numBytes += cVar_init_f(&cVar_fqlbZsmk, 0.0f);
  numBytes += cVar_init_f(&cVar_7EAIwm9u, 0.0f);
  numBytes += cVar_init_f(&cVar_cy1LoYEz, 0.0f);
  numBytes += cVar_init_f(&cVar_LoW9HGrd, 0.0f);
  numBytes += cSlice_init(&cSlice_fjPvU2Ka, 1, -1);
  numBytes += cVar_init_f(&cVar_UGCOqc8F, 1337.0f);
  numBytes += cVar_init_f(&cVar_J61wQ1d8, 0.0f);
  numBytes += cIf_init(&cIf_aUbSqvIa, false);
  numBytes += cIf_init(&cIf_vOLhs2tu, false);
  numBytes += cBinop_init(&cBinop_zqJfRQkd, 0.0f); // __pow
  numBytes += cIf_init(&cIf_FZxlrops, false);
  numBytes += cBinop_init(&cBinop_NBqs5iFP, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ZbK0MSdu, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ggrBwQ2V, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_akYTqPxL, 0.0f);
  numBytes += cIf_init(&cIf_Gq47oMYB, false);
  numBytes += cIf_init(&cIf_rLWbJHqM, false);
  numBytes += cBinop_init(&cBinop_gU577AkT, 0.0f); // __pow
  numBytes += cIf_init(&cIf_jjmyi90c, false);
  numBytes += cBinop_init(&cBinop_G4YxmF9n, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_RQ7IGHe7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_6LDR2eid, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hm4Ljawj, 0.0f);
  numBytes += cIf_init(&cIf_JsBLs8PC, false);
  numBytes += cIf_init(&cIf_QIMigpYg, false);
  numBytes += cBinop_init(&cBinop_z2dqcRXl, 0.0f); // __pow
  numBytes += cIf_init(&cIf_zIx5Y7G1, false);
  numBytes += cBinop_init(&cBinop_HI4jA9pI, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_NKhjj4AJ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_rwEXGku5, -15.0f); // __eq
  numBytes += cIf_init(&cIf_hOGgeWks, false);
  numBytes += cSlice_init(&cSlice_jPwH1bWz, 1, -1);
  numBytes += cVar_init_f(&cVar_5dTwTVBF, 0.0f);
  numBytes += cSlice_init(&cSlice_egvYrrNx, 1, -1);
  numBytes += cVar_init_f(&cVar_aiUIZYm4, 0.0f);
  numBytes += cSlice_init(&cSlice_joaC4Lbx, 1, -1);
  numBytes += cVar_init_f(&cVar_8EBCAkRx, 0.0f);
  numBytes += cSlice_init(&cSlice_FENWZTsH, 1, -1);
  numBytes += cVar_init_f(&cVar_0CJfr7D7, 0.313f);
  numBytes += cBinop_init(&cBinop_nwbzAeL9, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_zXDE21V8, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_GAfMaIsS, 0.0f);
  numBytes += cVar_init_f(&cVar_E96fJQ3Y, 1337.0f);
  numBytes += cVar_init_f(&cVar_Ku8dkO7U, 0.3f);
  numBytes += cBinop_init(&cBinop_oLA8Y5p5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9M9JZpSp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YvsaXMzF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ndkm0VBj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rBulmAct, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HUX2lJHc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E5w5myUw, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_pbdbUtDF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_WI7cwfe4, 0.0f);
  numBytes += cVar_init_f(&cVar_kVcRnUnt, 1337.0f);
  numBytes += cVar_init_f(&cVar_87RYnnBi, 0.313f);
  numBytes += cBinop_init(&cBinop_cCnTeb9J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DzvdJxRX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Wqsc8g8z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LdnUVG8J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yl5ckcoR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cPe44RzG, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ASEDhCN5, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_6JeUkzwV, 0.0f);
  numBytes += cVar_init_f(&cVar_csUuJxOR, 1037.0f);
  numBytes += cVar_init_f(&cVar_g0Fh8gqs, 0.4f);
  numBytes += cBinop_init(&cBinop_a0O1bQdv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hPahyKot, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rz5fhews, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hTuaBJaJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lGkVunSz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ta3Z2g6q, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_rCf65dAC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eEKIcJ0M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EvVZSuUF, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_nbJ5gziT, 1, -1);
  numBytes += cVar_init_f(&cVar_MXhkHKzD, 1337.0f);
  numBytes += cVar_init_f(&cVar_FzMnO1gj, 0.0f);
  numBytes += cIf_init(&cIf_weZmvf1w, false);
  numBytes += cIf_init(&cIf_VM4aKiJI, false);
  numBytes += cBinop_init(&cBinop_sDoU1v28, 0.0f); // __pow
  numBytes += cIf_init(&cIf_VvxKsQmI, false);
  numBytes += cBinop_init(&cBinop_3Eio7CVd, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_rQ7x8FHm, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_IbrATILc, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hAsCb00g, 0.0f);
  numBytes += cIf_init(&cIf_m0QA8fhj, false);
  numBytes += cIf_init(&cIf_IBq8ZoFm, false);
  numBytes += cBinop_init(&cBinop_EjW1a7cv, 0.0f); // __pow
  numBytes += cIf_init(&cIf_j0dqU1Uz, false);
  numBytes += cBinop_init(&cBinop_7XgyaR14, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ozfKo2Au, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_JRQmHFf4, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_QtQLCsax, 0.0f);
  numBytes += cIf_init(&cIf_VDFoIelE, false);
  numBytes += cIf_init(&cIf_lp5KuTSQ, false);
  numBytes += cBinop_init(&cBinop_qlBc0dLP, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ZLiNeWIE, false);
  numBytes += cBinop_init(&cBinop_DZEGuGHm, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bplwHjR2, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_z1QHqH3E, -15.0f); // __eq
  numBytes += cIf_init(&cIf_PWoiz38Z, false);
  numBytes += cSlice_init(&cSlice_ZPHRihFj, 1, -1);
  numBytes += cVar_init_f(&cVar_PHHGBeU3, 0.0f);
  numBytes += cSlice_init(&cSlice_LEVNJ21o, 1, -1);
  numBytes += cVar_init_f(&cVar_Fl2uB7TG, 0.0f);
  numBytes += cSlice_init(&cSlice_rL0Odllu, 1, -1);
  numBytes += cVar_init_f(&cVar_qAvo5lCq, 0.0f);
  numBytes += cSlice_init(&cSlice_2OQsem4g, 1, -1);
  numBytes += cVar_init_f(&cVar_LLkZVMZp, 0.313f);
  numBytes += cBinop_init(&cBinop_c8RrDi9x, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Ej46nWqK, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_TCacLTiT, 0.0f);
  numBytes += cVar_init_f(&cVar_Rsxbxg70, 1337.0f);
  numBytes += cVar_init_f(&cVar_fu5UMziG, 0.3f);
  numBytes += cBinop_init(&cBinop_DKmbqZiG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JCU1G8VB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fQGiRvTc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gpbnFl1z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oo4rvqx0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5rzt7ZkY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_e8pKNZmm, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ZeUJwLSM, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_AXeth0ii, 0.0f);
  numBytes += cVar_init_f(&cVar_hklrohLO, 1337.0f);
  numBytes += cVar_init_f(&cVar_VQX33lxx, 0.313f);
  numBytes += cBinop_init(&cBinop_TQGsyTgb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sYVacgUa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zaIc6u0J, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IxfWUucn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XjgwMogv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UHIuXrm4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_bXcEWQos, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Tk7wbDju, 0.0f);
  numBytes += cVar_init_f(&cVar_iU20sANk, 1037.0f);
  numBytes += cVar_init_f(&cVar_r7Ic28HB, 0.4f);
  numBytes += cBinop_init(&cBinop_NxkpoEnF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KaMKI0ag, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AnCa5dpF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_M7TzZxW6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZWML31dx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ONEeLOnE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_m6yyeqmq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lPWAyAws, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kWfAjVAj, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ebjKyx0y, 5705.6f);
  numBytes += cVar_init_f(&cVar_3umFd9U7, 313.3f);
  numBytes += cBinop_init(&cBinop_KrPGhI5d, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_HOLKWDBI, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_AoLzyctW, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_VBwxo2cP, 0.0f);
  numBytes += cVar_init_f(&cVar_GtlG1wmK, 0.0f);
  numBytes += cVar_init_f(&cVar_YuDNY926, 0.0f);
  numBytes += cVar_init_f(&cVar_toay3Pec, 0.0f);
  numBytes += cVar_init_f(&cVar_HY2BuXad, 0.0f);
  numBytes += cVar_init_f(&cVar_uNZ24ifZ, 0.0f);
  numBytes += cVar_init_f(&cVar_P6igpHWH, 0.0f);
  numBytes += cVar_init_f(&cVar_kuJBzgeG, 0.0f);
  numBytes += cVar_init_f(&cVar_6mjCROqc, 0.0f);
  numBytes += cVar_init_f(&cVar_nhybzyDZ, 0.0f);
  numBytes += cVar_init_f(&cVar_kGnYEtj0, 0.0f);
  numBytes += cVar_init_f(&cVar_iWvJ3dfq, 0.0f);
  numBytes += cVar_init_s(&cVar_rY2Ni6aI, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_w3Ac0I6O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_934Ar2XD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nZ6VcltP, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_3mpFVBkQ, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_GmIHzg1W, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CYbmWLks, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_x00S5JIi, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_Nrx9Rhkl, 0.0f);
  numBytes += cDelay_init(this, &cDelay_S09pkwOl, 0.0f);
  numBytes += hTable_init(&hTable_jnZsI60y, 256);
  numBytes += cDelay_init(this, &cDelay_tgblDrs1, 0.0f);
  numBytes += cDelay_init(this, &cDelay_M4fuccsM, 0.0f);
  numBytes += hTable_init(&hTable_aHAKQoE2, 256);
  numBytes += cVar_init_f(&cVar_DONRwUuD, 14.0f);
  numBytes += cBinop_init(&cBinop_7pCQXoMC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_zQYeIUJM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YyI2gZZF, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_spvGxTZp, 14.0f);
  numBytes += cBinop_init(&cBinop_bG4iPpd0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_2hgeWFTa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IguPLy0M, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_fkgrvBq4, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_YqBW7xPm, 1, -1);
  numBytes += cVar_init_f(&cVar_wwoqu8Ek, 0.2f);
  numBytes += cSlice_init(&cSlice_7fPxJjyy, 1, -1);
  numBytes += cVar_init_f(&cVar_CvSMFJ2D, 0.0f);
  numBytes += cSlice_init(&cSlice_PpA9Y4Vh, 1, -1);
  numBytes += cVar_init_f(&cVar_C7dIQyVo, 2.0f);
  numBytes += cSlice_init(&cSlice_dQmcmQ8z, 1, -1);
  numBytes += cVar_init_f(&cVar_gvQ3PsoN, 0.5f);
  numBytes += cVar_init_s(&cVar_360yI5Sa, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_ik8TzPwN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uhAuy5yH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uc0CnL8k, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_jQpJqLNV, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_sMxWsk9O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AT6KK8dy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Xyz9qgpd, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_t3eaQqYi, 0.0f);
  numBytes += cDelay_init(this, &cDelay_87krexGQ, 0.0f);
  numBytes += hTable_init(&hTable_T3T3Uyfm, 256);
  numBytes += cDelay_init(this, &cDelay_1hFaqHyt, 0.0f);
  numBytes += cDelay_init(this, &cDelay_O55kkzCp, 0.0f);
  numBytes += hTable_init(&hTable_ob9XAt1H, 256);
  numBytes += cVar_init_f(&cVar_g6z9RGgO, 14.0f);
  numBytes += cBinop_init(&cBinop_xSvVmZbn, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_3i3pakgZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X3F7zLgQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_nWOuTNmN, 14.0f);
  numBytes += cBinop_init(&cBinop_LhNEZ7KR, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_0PyQMCF1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1DWs3hhB, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_xJQDAZI7, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_qtGZFDe0, 1, -1);
  numBytes += cVar_init_f(&cVar_X9ufwYLs, 0.2f);
  numBytes += cSlice_init(&cSlice_EalRrZWG, 1, -1);
  numBytes += cVar_init_f(&cVar_GOuzTRfY, 0.0f);
  numBytes += cSlice_init(&cSlice_v0M7akzD, 1, -1);
  numBytes += cVar_init_f(&cVar_ngELj3Po, 2.0f);
  numBytes += cSlice_init(&cSlice_GXFqSbHx, 1, -1);
  numBytes += cVar_init_f(&cVar_B0Z0uRxu, 0.5f);
  numBytes += cVar_init_s(&cVar_CIKQAU3i, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_XsKCuS5Z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6pdHMJ1x, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qJb5nb1I, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_5DO2Y6xA, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_dBDD2B7N, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0FEBFhts, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_phgIFGG5, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_x3aTmfk2, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xYomTTP5, 0.0f);
  numBytes += hTable_init(&hTable_nRN7JZHi, 256);
  numBytes += cDelay_init(this, &cDelay_93F2wLzF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_mDolioFR, 0.0f);
  numBytes += hTable_init(&hTable_WHfFeRML, 256);
  numBytes += cVar_init_f(&cVar_4N0XHdA4, 14.0f);
  numBytes += cBinop_init(&cBinop_HybtfPFH, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VfIuVmZb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iNpA9lGy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NllfuXb0, 14.0f);
  numBytes += cBinop_init(&cBinop_HNSpxT6J, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_IFfd8ufL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gur3ZBXM, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_Tfbw0NDJ, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_gmECyTW7, 1, -1);
  numBytes += cVar_init_f(&cVar_spswMe3Y, 0.2f);
  numBytes += cSlice_init(&cSlice_sIbekN4R, 1, -1);
  numBytes += cVar_init_f(&cVar_qm8x6zut, 0.0f);
  numBytes += cSlice_init(&cSlice_5dBSkdHm, 1, -1);
  numBytes += cVar_init_f(&cVar_qkgQIIkS, 2.0f);
  numBytes += cSlice_init(&cSlice_iYtuupQD, 1, -1);
  numBytes += cVar_init_f(&cVar_KGPzC9gR, 0.5f);
  numBytes += sVarf_init(&sVarf_npEVCbwm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UTkAm23H, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0P97rpXv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9kvRD8qS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6lE6kiqn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_A6ImbY59, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_jnZsI60y);
  hTable_free(&hTable_aHAKQoE2);
  hTable_free(&hTable_T3T3Uyfm);
  hTable_free(&hTable_ob9XAt1H);
  hTable_free(&hTable_nRN7JZHi);
  hTable_free(&hTable_WHfFeRML);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_jnZsI60y; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_aHAKQoE2; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_T3T3Uyfm; // del-1397-flanger-r
    case 0x578173CB: return &hTable_ob9XAt1H; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_nRN7JZHi; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_WHfFeRML; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iyCCkqsR_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sca2YuuG_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nK3PzB8b_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O3FoI75s_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Zr55k2k3_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JNBCndHN_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SUBhYq2B_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nQyhFVE0_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Omo8v3t3_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7GwN5yNi_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bRrQJ9wQ_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IXflUxJK_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qCHNB9eh_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eUtxsJFT_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9TZA1ipO_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fDG2IbFf_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lTRdEPJS_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EIpUk3gU_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6eOwjrO3_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4910ls9X_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6eWr1Qxa_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KDUapOMK_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_paC1cnF9_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bTiTytwn_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NDgOpgWz_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q5MxoafW_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_y4v4IJdN_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7N3Vx8BF_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KpRjkZsf_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wx7G1p2A_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RAj5aiC9_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_39pu3fFG_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_B01AM6Yo_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SN4WIcqc_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XPp4P5aQ_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LJKP9nxn_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_whgrPFHm_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dJtrUIMr_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3bGXocU6_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pm0A4bHt_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qbgvGIyU_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kVEPs1Nh_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_twhqpFpE_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0pDGdU8o_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qBmm7jG4_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kCn7eYEX_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xQYIshNO_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6VQxa9CL_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_baDp2gRe_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LTOuWRNh_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vCxRgtEr_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7mwLs9Xw_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IrlRO4VM_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ohd0Jy8c_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mPwRYsnd_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7igK9azj_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SEyRRcOX_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_fqlbZsmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PZqTUYXu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_7EAIwm9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BRd4kknL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_cy1LoYEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SzHokyVf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_LoW9HGrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nPQgh4ZU_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i6W5l5VH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RD6Bg9d6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ksg5HBh7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_9G7GckYJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fjPvU2Ka, 0, m, &cSlice_fjPvU2Ka_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UWRWZc62_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_fjPvU2Ka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_q5flTTYq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_q5flTTYq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_UGCOqc8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q5flTTYq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_q5flTTYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6eOwjrO3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_J61wQ1d8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_42ivgxfb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_aUbSqvIa, 0, m, &cIf_aUbSqvIa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_aUbSqvIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4QLPvtZH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_vOLhs2tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_jvNJwPeS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_d7aN51ya_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_dbw3POjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zqJfRQkd, HV_BINOP_POW, 0, m, &cBinop_zqJfRQkd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zqJfRQkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FZxlrops, 0, m, &cIf_FZxlrops_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BK2ofIa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0sQbfuUC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_G4zh8CWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vOLhs2tu, 0, m, &cIf_vOLhs2tu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GS3XjKQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hRNeNsMx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hRNeNsMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vOLhs2tu, 1, m, &cIf_vOLhs2tu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_d7aN51ya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_BK2ofIa9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jvNJwPeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_FZxlrops, 0, m, &cIf_FZxlrops_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0sQbfuUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zqJfRQkd, HV_BINOP_POW, 1, m, &cBinop_zqJfRQkd_sendMessage);
  cMsg_dbw3POjh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_FZxlrops_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_rCf65dAC, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_42ivgxfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aUbSqvIa, 1, m, &cIf_aUbSqvIa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4QLPvtZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZbK0MSdu, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ZbK0MSdu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ggrBwQ2V, HV_BINOP_EQ, 1, m, &cBinop_ggrBwQ2V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DTN00piB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NBqs5iFP, HV_BINOP_ADD, 0, m, &cBinop_NBqs5iFP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NBqs5iFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GS3XjKQQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G4zh8CWk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZbK0MSdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FZxlrops, 1, m, &cIf_FZxlrops_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ggrBwQ2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oqf26jjc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_oqf26jjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rCf65dAC, m);
}

void Heavy_WSTD_FL3NGR::cCast_2A8DkVbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_J61wQ1d8, 0, m, &cVar_J61wQ1d8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LNt4fu9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NBqs5iFP, HV_BINOP_ADD, 1, m, &cBinop_NBqs5iFP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZbK0MSdu, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ZbK0MSdu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ggrBwQ2V, HV_BINOP_EQ, 0, m, &cBinop_ggrBwQ2V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_j5N3EClS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DTN00piB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_akYTqPxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VImNavu4_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Gq47oMYB, 0, m, &cIf_Gq47oMYB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_Gq47oMYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FyQxjZfy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_rLWbJHqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kpv5RRt7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_RcN7ZaIb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_CDM11FLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gU577AkT, HV_BINOP_POW, 0, m, &cBinop_gU577AkT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gU577AkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jjmyi90c, 0, m, &cIf_jjmyi90c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0Cp0f8Dw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_4zThlwl7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gBXOE644_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rLWbJHqM, 0, m, &cIf_rLWbJHqM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XOyh0nuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FhBHbmlF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FhBHbmlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rLWbJHqM, 1, m, &cIf_rLWbJHqM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RcN7ZaIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_0Cp0f8Dw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kpv5RRt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_jjmyi90c, 0, m, &cIf_jjmyi90c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4zThlwl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gU577AkT, HV_BINOP_POW, 1, m, &cBinop_gU577AkT_sendMessage);
  cMsg_CDM11FLg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_jjmyi90c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pBS9L0eY_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gumjcdGW_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Ac4L9dan_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_VImNavu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gq47oMYB, 1, m, &cIf_Gq47oMYB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FyQxjZfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RQ7IGHe7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_RQ7IGHe7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6LDR2eid, HV_BINOP_EQ, 1, m, &cBinop_6LDR2eid_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FURAvHAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_G4YxmF9n, HV_BINOP_ADD, 0, m, &cBinop_G4YxmF9n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G4YxmF9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XOyh0nuk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gBXOE644_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RQ7IGHe7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jjmyi90c, 1, m, &cIf_jjmyi90c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6LDR2eid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SzFx0GFM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_SzFx0GFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pBS9L0eY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gumjcdGW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Ac4L9dan_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TaTWyRNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G4YxmF9n, HV_BINOP_ADD, 1, m, &cBinop_G4YxmF9n_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RQ7IGHe7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_RQ7IGHe7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6LDR2eid, HV_BINOP_EQ, 0, m, &cBinop_6LDR2eid_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_a0gTVFyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_akYTqPxL, 0, m, &cVar_akYTqPxL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FCdKrxwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FURAvHAl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_hm4Ljawj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wHiC0LDr_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_JsBLs8PC, 0, m, &cIf_JsBLs8PC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_JsBLs8PC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_y40ol8vb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_QIMigpYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_GTcuTArY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_cHauH5OC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_rP3WIaLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_z2dqcRXl, HV_BINOP_POW, 0, m, &cBinop_z2dqcRXl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z2dqcRXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zIx5Y7G1, 0, m, &cIf_zIx5Y7G1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vlwsk3T9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_k4UxG3e2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BTcE8ceI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QIMigpYg, 0, m, &cIf_QIMigpYg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0bBg0yZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wvXlEyTv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wvXlEyTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QIMigpYg, 1, m, &cIf_QIMigpYg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cHauH5OC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_vlwsk3T9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GTcuTArY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_zIx5Y7G1, 0, m, &cIf_zIx5Y7G1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_k4UxG3e2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z2dqcRXl, HV_BINOP_POW, 1, m, &cBinop_z2dqcRXl_sendMessage);
  cMsg_rP3WIaLx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_zIx5Y7G1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_EvVZSuUF, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_wHiC0LDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JsBLs8PC, 1, m, &cIf_JsBLs8PC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y40ol8vb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NKhjj4AJ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_NKhjj4AJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rwEXGku5, HV_BINOP_EQ, 1, m, &cBinop_rwEXGku5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jdFV7U9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HI4jA9pI, HV_BINOP_ADD, 0, m, &cBinop_HI4jA9pI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HI4jA9pI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0bBg0yZ1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BTcE8ceI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NKhjj4AJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zIx5Y7G1, 1, m, &cIf_zIx5Y7G1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rwEXGku5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KWjwOVIH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_KWjwOVIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EvVZSuUF, m);
}

void Heavy_WSTD_FL3NGR::cCast_14aVFDbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jdFV7U9D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_cDj4YD3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HI4jA9pI, HV_BINOP_ADD, 1, m, &cBinop_HI4jA9pI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NKhjj4AJ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_NKhjj4AJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rwEXGku5, HV_BINOP_EQ, 0, m, &cBinop_rwEXGku5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_aY3hEFHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hm4Ljawj, 0, m, &cVar_hm4Ljawj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_hOGgeWks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_eEKIcJ0M, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_DJQK5dKY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jPwH1bWz, 0, m, &cSlice_jPwH1bWz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vaY9h4UR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jPwH1bWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_O76FYFsh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_O76FYFsh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_5dTwTVBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_O76FYFsh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_O76FYFsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lTRdEPJS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_vaY9h4UR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_egvYrrNx, 0, m, &cSlice_egvYrrNx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9G7GckYJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_egvYrrNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ok2PBNIv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ok2PBNIv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_aiUIZYm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ok2PBNIv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Ok2PBNIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6eWr1Qxa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_UWRWZc62_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_joaC4Lbx, 0, m, &cSlice_joaC4Lbx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_R4f86nWc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_joaC4Lbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fqVe5zkW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fqVe5zkW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_8EBCAkRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fqVe5zkW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_fqVe5zkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EIpUk3gU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_R4f86nWc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FENWZTsH, 0, m, &cSlice_FENWZTsH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_FENWZTsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_f3dNU963_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_f3dNU963_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_0CJfr7D7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f3dNU963_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_f3dNU963_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4910ls9X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_u6pMX2pz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3b5Lb9kK, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_X2oEeza1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5pdRwlUq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_NGgpwCjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_l70MpCB8, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_sQrodckf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0Xj2bOwj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2WbozdF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uies1ql3, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Dy0OTsQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7LKxm51C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_7LKxm51C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nwbzAeL9, HV_BINOP_DIVIDE, 1, m, &cBinop_nwbzAeL9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bgN4fdJS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_7fpSrQ6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_I2sYq25s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5Jz9TGQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_7fpSrQ6l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I2sYq25s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nwbzAeL9, HV_BINOP_DIVIDE, 0, m, &cBinop_nwbzAeL9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bgN4fdJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Jz9TGQH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nwbzAeL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zXDE21V8, HV_BINOP_MULTIPLY, 1, m, &cBinop_zXDE21V8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zXDE21V8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m5v1SOsp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BEnkzBk5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_88wx01ri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EV8ZO22G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_cSWBZfrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6x6o9Klk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CKGSX6rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Ut4W4STL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ut4W4STL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zXDE21V8, HV_BINOP_MULTIPLY, 0, m, &cBinop_zXDE21V8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_koHh2WdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_nJOWmMbQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nJOWmMbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hjQt77Et_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_L7sM47kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GAfMaIsS, 1, m, &cVar_GAfMaIsS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_GAfMaIsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TZWvNQ2h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_G9wdVqx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9M9JZpSp, HV_BINOP_MULTIPLY, 1, m, &cBinop_9M9JZpSp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1LB2SQKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_G9wdVqx5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3XFxFht4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IZJ9xaEq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IZJ9xaEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YvsaXMzF, HV_BINOP_MULTIPLY, 1, m, &cBinop_YvsaXMzF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y96gaIl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ndkm0VBj, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ndkm0VBj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mUfkI0tE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_y96gaIl7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KWejCt2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rBulmAct, HV_BINOP_MULTIPLY, 1, m, &cBinop_rBulmAct_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2rr8KVfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SfqPHYvQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SfqPHYvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HUX2lJHc, HV_BINOP_MULTIPLY, 1, m, &cBinop_HUX2lJHc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_E96fJQ3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G9EJqZnf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_CKGSX6rw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kp33tvYT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Ku8dkO7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_koHh2WdD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BEnkzBk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_cSWBZfrm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_m5v1SOsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_88wx01ri_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_EV8ZO22G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bTiTytwn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6x6o9Klk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_paC1cnF9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_i0XwrM4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KDUapOMK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_hjQt77Et_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Q4va7JGV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Q4va7JGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oLA8Y5p5, HV_BINOP_MULTIPLY, 1, m, &cBinop_oLA8Y5p5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oLA8Y5p5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Zo7JZgAM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Zo7JZgAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i0XwrM4G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_TZWvNQ2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9oD4SlVy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9oD4SlVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_20Gvu0EE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XxhFiGg2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WDGhtWtV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9xV8p1qN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XEagFl4b_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_38xLuyOS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9M9JZpSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u6pMX2pz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YvsaXMzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X2oEeza1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ndkm0VBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NGgpwCjz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rBulmAct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sQrodckf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HUX2lJHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2WbozdF5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_OhvQPHRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E96fJQ3Y, 0, m, &cVar_E96fJQ3Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nEiE472v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ku8dkO7U, 1, m, &cVar_Ku8dkO7U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WDGhtWtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rBulmAct, HV_BINOP_MULTIPLY, 0, m, &cBinop_rBulmAct_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XxhFiGg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HUX2lJHc, HV_BINOP_MULTIPLY, 0, m, &cBinop_HUX2lJHc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_38xLuyOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9M9JZpSp, HV_BINOP_MULTIPLY, 0, m, &cBinop_9M9JZpSp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XEagFl4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YvsaXMzF, HV_BINOP_MULTIPLY, 0, m, &cBinop_YvsaXMzF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_20Gvu0EE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_9xV8p1qN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ndkm0VBj, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ndkm0VBj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Kp33tvYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GAfMaIsS, 0, m, &cVar_GAfMaIsS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_G9EJqZnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ku8dkO7U, 0, m, &cVar_Ku8dkO7U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5Tu739V9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4ssQJkHF, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KO1u765N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_opJ0aZvt, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4N4nzXtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FCx1jg80, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_r49HKOX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wHT95bmE, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GgrGNRpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZXQsFILA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ZXQsFILA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E5w5myUw, HV_BINOP_DIVIDE, 1, m, &cBinop_E5w5myUw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xffMttbl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_p6NlnbQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_lqg9ubB0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CJoZ83Uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_p6NlnbQE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lqg9ubB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E5w5myUw, HV_BINOP_DIVIDE, 0, m, &cBinop_E5w5myUw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xffMttbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CJoZ83Uz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_E5w5myUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pbdbUtDF, HV_BINOP_MULTIPLY, 1, m, &cBinop_pbdbUtDF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pbdbUtDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oIC52AFY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F5OsdvkA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_TGtEzQ65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GodW3sNP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_QNMecev5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6UuMYkKF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XdSjZEjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_mMr8fTGu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mMr8fTGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pbdbUtDF, HV_BINOP_MULTIPLY, 0, m, &cBinop_pbdbUtDF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MXXFZLhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_D97NjR6I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D97NjR6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VfBYiTgY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DADF5uyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wqsc8g8z, HV_BINOP_MULTIPLY, 1, m, &cBinop_Wqsc8g8z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iwywSNiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WI7cwfe4, 1, m, &cVar_WI7cwfe4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iJCrRsZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LdnUVG8J, HV_BINOP_MULTIPLY, 1, m, &cBinop_LdnUVG8J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fGbz2oEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HpgSvwOw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HpgSvwOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yl5ckcoR, HV_BINOP_MULTIPLY, 1, m, &cBinop_yl5ckcoR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_WI7cwfe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xHxmEi7t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_kVcRnUnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xd9flR6Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XdSjZEjg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6Ac4rYa8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_87RYnnBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_MXXFZLhT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oIC52AFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_TGtEzQ65_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_F5OsdvkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_QNMecev5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_GodW3sNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_y4v4IJdN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6UuMYkKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Q5MxoafW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_TTrrBswf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NDgOpgWz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_VfBYiTgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_i02FKm2h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i02FKm2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cCnTeb9J, HV_BINOP_MULTIPLY, 1, m, &cBinop_cCnTeb9J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cCnTeb9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cJnfJRO6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cJnfJRO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TTrrBswf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_xHxmEi7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_djG0duWA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_djG0duWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iEvG29QD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5kGQwGUF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mbdxXe94_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JiIVC9Gy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DzvdJxRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Tu739V9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Wqsc8g8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KO1u765N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LdnUVG8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4N4nzXtC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yl5ckcoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r49HKOX3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_2mDj92PR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kVcRnUnt, 0, m, &cVar_kVcRnUnt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5HqIM7Yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_87RYnnBi, 1, m, &cVar_87RYnnBi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6Ac4rYa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WI7cwfe4, 0, m, &cVar_WI7cwfe4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Xd9flR6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_87RYnnBi, 0, m, &cVar_87RYnnBi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iEvG29QD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yl5ckcoR, HV_BINOP_MULTIPLY, 0, m, &cBinop_yl5ckcoR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JiIVC9Gy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DzvdJxRX, HV_BINOP_MULTIPLY, 0, m, &cBinop_DzvdJxRX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mbdxXe94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wqsc8g8z, HV_BINOP_MULTIPLY, 0, m, &cBinop_Wqsc8g8z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5kGQwGUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LdnUVG8J, HV_BINOP_MULTIPLY, 0, m, &cBinop_LdnUVG8J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_42cBRPNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_11sNIWlK, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_aI8xJAGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t75ki2MV, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_fVtJu87n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Zb6YUBu5, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_JI2wvZOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VEq3rhW4, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_kjId4a9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_76njA3SW, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Ld8UoYTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_48fChft0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_48fChft0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cPe44RzG, HV_BINOP_DIVIDE, 1, m, &cBinop_cPe44RzG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zIq9ckVh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Ry4gzESz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ZtxJyNh8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rJB5Azj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Ry4gzESz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZtxJyNh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cPe44RzG, HV_BINOP_DIVIDE, 0, m, &cBinop_cPe44RzG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zIq9ckVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rJB5Azj8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cPe44RzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ASEDhCN5, HV_BINOP_MULTIPLY, 1, m, &cBinop_ASEDhCN5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ASEDhCN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qffPHxoA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7bwq8I7F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_xJErPuFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KRdfsUGI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_ksm7DvCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oFVbYSpG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qfxPys6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_FBkNitNx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FBkNitNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ASEDhCN5, HV_BINOP_MULTIPLY, 0, m, &cBinop_ASEDhCN5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iRWQNL8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_KRUBjdmI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KRUBjdmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H1JVYnb5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dlmjLXK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hPahyKot, HV_BINOP_MULTIPLY, 1, m, &cBinop_hPahyKot_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kUmcF0AD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_D1uvVP1H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D1uvVP1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dlmjLXK4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XmUwH90X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_La53XKon_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_La53XKon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rz5fhews, HV_BINOP_MULTIPLY, 1, m, &cBinop_rz5fhews_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SiTj872I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hTuaBJaJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_hTuaBJaJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4rN4xdko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_133Erjps_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_133Erjps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SiTj872I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Jw3n6P4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6JeUkzwV, 1, m, &cVar_6JeUkzwV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8QODElVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lGkVunSz, HV_BINOP_MULTIPLY, 1, m, &cBinop_lGkVunSz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_aKNoirTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jXzN42Ey_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jXzN42Ey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ta3Z2g6q, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ta3Z2g6q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_6JeUkzwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_elgdLMuw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_csUuJxOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G2sajEJC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_qfxPys6f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5jilm2nV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_g0Fh8gqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_iRWQNL8L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qffPHxoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_xJErPuFD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7bwq8I7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ksm7DvCy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_KRdfsUGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wx7G1p2A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_oFVbYSpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KpRjkZsf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_10RVyFx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7N3Vx8BF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_H1JVYnb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UM70lKaL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UM70lKaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a0O1bQdv, HV_BINOP_MULTIPLY, 1, m, &cBinop_a0O1bQdv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_a0O1bQdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tmdBCXmt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tmdBCXmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_10RVyFx6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_elgdLMuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oLM6v9AH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oLM6v9AH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e3M4tF5p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WUKaK0R6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VPutRi8s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rICOhhZa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lt6q6OLN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HvPQJSNp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hPahyKot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_42cBRPNW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rz5fhews_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aI8xJAGm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hTuaBJaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fVtJu87n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lGkVunSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JI2wvZOz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ta3Z2g6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kjId4a9C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_AYmC6kQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_csUuJxOR, 0, m, &cVar_csUuJxOR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Us0pHNac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g0Fh8gqs, 1, m, &cVar_g0Fh8gqs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rICOhhZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hTuaBJaJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_hTuaBJaJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_e3M4tF5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_HvPQJSNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hPahyKot, HV_BINOP_MULTIPLY, 0, m, &cBinop_hPahyKot_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lt6q6OLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rz5fhews, HV_BINOP_MULTIPLY, 0, m, &cBinop_rz5fhews_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WUKaK0R6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ta3Z2g6q, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ta3Z2g6q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VPutRi8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lGkVunSz, HV_BINOP_MULTIPLY, 0, m, &cBinop_lGkVunSz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5jilm2nV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6JeUkzwV, 0, m, &cVar_6JeUkzwV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_G2sajEJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g0Fh8gqs, 0, m, &cVar_g0Fh8gqs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pBS9L0eY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hOGgeWks, 1, m, &cIf_hOGgeWks_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kQxf5Fm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eEKIcJ0M, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gumjcdGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kQxf5Fm2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ac4L9dan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hOGgeWks, 0, m, &cIf_hOGgeWks_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_KlA0UwUN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nbJ5gziT, 0, m, &cSlice_nbJ5gziT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xDDA3tf7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_nbJ5gziT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FdWQYjrA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FdWQYjrA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_MXhkHKzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FdWQYjrA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_FdWQYjrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_B01AM6Yo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_FzMnO1gj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XRMLGZlX_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_weZmvf1w, 0, m, &cIf_weZmvf1w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_weZmvf1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_RUWvxVfW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_VM4aKiJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_C05FYfVU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_aOdSrdeX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_ksXNkCST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sDoU1v28, HV_BINOP_POW, 0, m, &cBinop_sDoU1v28_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sDoU1v28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VvxKsQmI, 0, m, &cIf_VvxKsQmI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FrmXENbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_2Qp5VOIj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_osjjVopp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QfbkTUQ8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_viF88Wuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VM4aKiJI, 0, m, &cIf_VM4aKiJI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QfbkTUQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VM4aKiJI, 1, m, &cIf_VM4aKiJI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aOdSrdeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_FrmXENbg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_C05FYfVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VvxKsQmI, 0, m, &cIf_VvxKsQmI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2Qp5VOIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sDoU1v28, HV_BINOP_POW, 1, m, &cBinop_sDoU1v28_sendMessage);
  cMsg_ksXNkCST_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_VvxKsQmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_m6yyeqmq, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_XRMLGZlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_weZmvf1w, 1, m, &cIf_weZmvf1w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RUWvxVfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQ7x8FHm, HV_BINOP_GREATER_THAN, 1, m, &cBinop_rQ7x8FHm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IbrATILc, HV_BINOP_EQ, 1, m, &cBinop_IbrATILc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_D99fpbZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3Eio7CVd, HV_BINOP_ADD, 0, m, &cBinop_3Eio7CVd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3Eio7CVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_osjjVopp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_viF88Wuu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rQ7x8FHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VvxKsQmI, 1, m, &cIf_VvxKsQmI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IbrATILc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tx69H0SQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Tx69H0SQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_m6yyeqmq, m);
}

void Heavy_WSTD_FL3NGR::cCast_Uo6QREnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D99fpbZJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_33v665em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3Eio7CVd, HV_BINOP_ADD, 1, m, &cBinop_3Eio7CVd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQ7x8FHm, HV_BINOP_GREATER_THAN, 0, m, &cBinop_rQ7x8FHm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IbrATILc, HV_BINOP_EQ, 0, m, &cBinop_IbrATILc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2Of527Xp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FzMnO1gj, 0, m, &cVar_FzMnO1gj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_hAsCb00g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4OinPoYm_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_m0QA8fhj, 0, m, &cIf_m0QA8fhj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_m0QA8fhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WpfbBkma_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_IBq8ZoFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3s86exCV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_wRhg35JB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_5zbbjOI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EjW1a7cv, HV_BINOP_POW, 0, m, &cBinop_EjW1a7cv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EjW1a7cv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j0dqU1Uz, 0, m, &cIf_j0dqU1Uz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fAR6y9fQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_wG6zo2vW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zJompdiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IBq8ZoFm, 0, m, &cIf_IBq8ZoFm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kbQ1HoAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dCVWFcUc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dCVWFcUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IBq8ZoFm, 1, m, &cIf_IBq8ZoFm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wRhg35JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_fAR6y9fQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3s86exCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_j0dqU1Uz, 0, m, &cIf_j0dqU1Uz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wG6zo2vW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EjW1a7cv, HV_BINOP_POW, 1, m, &cBinop_EjW1a7cv_sendMessage);
  cMsg_5zbbjOI4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_j0dqU1Uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NEPFcRDb_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_z1yEX9Oy_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_1idFxDJO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_4OinPoYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m0QA8fhj, 1, m, &cIf_m0QA8fhj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WpfbBkma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ozfKo2Au, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ozfKo2Au_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JRQmHFf4, HV_BINOP_EQ, 1, m, &cBinop_JRQmHFf4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ddsVfzFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7XgyaR14, HV_BINOP_ADD, 0, m, &cBinop_7XgyaR14_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7XgyaR14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kbQ1HoAh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zJompdiv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ozfKo2Au_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j0dqU1Uz, 1, m, &cIf_j0dqU1Uz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JRQmHFf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KlTmsQO1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_KlTmsQO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NEPFcRDb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_z1yEX9Oy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_1idFxDJO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0y2jNbZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hAsCb00g, 0, m, &cVar_hAsCb00g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_45QFIhgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ddsVfzFk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_WRTWF2mN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7XgyaR14, HV_BINOP_ADD, 1, m, &cBinop_7XgyaR14_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ozfKo2Au, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ozfKo2Au_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JRQmHFf4, HV_BINOP_EQ, 0, m, &cBinop_JRQmHFf4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_QtQLCsax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vFF4OrFU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VDFoIelE, 0, m, &cIf_VDFoIelE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_VDFoIelE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5HoV87tX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_lp5KuTSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7oYJzR3m_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_aqFBBbxT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_EuqQxFtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qlBc0dLP, HV_BINOP_POW, 0, m, &cBinop_qlBc0dLP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qlBc0dLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZLiNeWIE, 0, m, &cIf_ZLiNeWIE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CUs6iGX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_DHZeB1NQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OXw074wK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lp5KuTSQ, 0, m, &cIf_lp5KuTSQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7KqvpXNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JUjETCFu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JUjETCFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lp5KuTSQ, 1, m, &cIf_lp5KuTSQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aqFBBbxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_CUs6iGX8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7oYJzR3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZLiNeWIE, 0, m, &cIf_ZLiNeWIE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DHZeB1NQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qlBc0dLP, HV_BINOP_POW, 1, m, &cBinop_qlBc0dLP_sendMessage);
  cMsg_EuqQxFtH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_ZLiNeWIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_kWfAjVAj, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_vFF4OrFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VDFoIelE, 1, m, &cIf_VDFoIelE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5HoV87tX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bplwHjR2, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bplwHjR2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_z1QHqH3E, HV_BINOP_EQ, 1, m, &cBinop_z1QHqH3E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_P5IstO25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DZEGuGHm, HV_BINOP_ADD, 0, m, &cBinop_DZEGuGHm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DZEGuGHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7KqvpXNa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OXw074wK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bplwHjR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZLiNeWIE, 1, m, &cIf_ZLiNeWIE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z1QHqH3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eLmg80QJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_eLmg80QJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kWfAjVAj, m);
}

void Heavy_WSTD_FL3NGR::cCast_EFE2tU7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P5IstO25_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_UeixTajd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DZEGuGHm, HV_BINOP_ADD, 1, m, &cBinop_DZEGuGHm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bplwHjR2, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bplwHjR2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_z1QHqH3E, HV_BINOP_EQ, 0, m, &cBinop_z1QHqH3E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5lcZDQJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QtQLCsax, 0, m, &cVar_QtQLCsax_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_PWoiz38Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_lPWAyAws, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zWY2mRgV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZPHRihFj, 0, m, &cSlice_ZPHRihFj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9Sr4Ouwb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ZPHRihFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HjwlwQSG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HjwlwQSG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_PHHGBeU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HjwlwQSG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_HjwlwQSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RAj5aiC9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_9Sr4Ouwb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LEVNJ21o, 0, m, &cSlice_LEVNJ21o_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KlA0UwUN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_LEVNJ21o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4XFJ2j9j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4XFJ2j9j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Fl2uB7TG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4XFJ2j9j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4XFJ2j9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XPp4P5aQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_xDDA3tf7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rL0Odllu, 0, m, &cSlice_rL0Odllu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5THQdBQq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_rL0Odllu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SnZ47zKw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SnZ47zKw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_qAvo5lCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SnZ47zKw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_SnZ47zKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_39pu3fFG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_5THQdBQq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2OQsem4g, 0, m, &cSlice_2OQsem4g_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_2OQsem4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GKj2G85D_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GKj2G85D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_LLkZVMZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GKj2G85D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_GKj2G85D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SN4WIcqc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_B1T6AMQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WERGYbFl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xyaMlTzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uNxrLsaW, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_K38g28n3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CGvrdPyX, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6sqzdC3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DrdgR2fq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_0cPCmXpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2mtPhHh7, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_dMMx60uQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7jSZeXdu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_7jSZeXdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c8RrDi9x, HV_BINOP_DIVIDE, 1, m, &cBinop_c8RrDi9x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wBAsFHNR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_kI3ZGrRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_BHnJ72eT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2NSaMOL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_kI3ZGrRe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BHnJ72eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c8RrDi9x, HV_BINOP_DIVIDE, 0, m, &cBinop_c8RrDi9x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wBAsFHNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2NSaMOL6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_c8RrDi9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ej46nWqK, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ej46nWqK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ej46nWqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AcnSdfjr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6f87dewq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_l3tZLj1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P9DQPp0Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_Kg1SGLs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_j7iBnBWq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_iMDSChbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_XpAyh7UQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XpAyh7UQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ej46nWqK, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ej46nWqK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z2Y7Sgrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_a09PvGcU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_a09PvGcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hCdngQBb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4yUM5a5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TCacLTiT, 1, m, &cVar_TCacLTiT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_TCacLTiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0kWKpbLS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UunX52Mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JCU1G8VB, HV_BINOP_MULTIPLY, 1, m, &cBinop_JCU1G8VB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qQjwEyqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UunX52Mp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YhhgBQXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gLGLJw3H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gLGLJw3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fQGiRvTc, HV_BINOP_MULTIPLY, 1, m, &cBinop_fQGiRvTc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ys1Ecn0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gpbnFl1z, HV_BINOP_MULTIPLY, 1, m, &cBinop_gpbnFl1z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KsFwobxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ys1Ecn0D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PAYiRGzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oo4rvqx0, HV_BINOP_MULTIPLY, 1, m, &cBinop_oo4rvqx0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_usrKX4pR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8uGXLVmv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8uGXLVmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5rzt7ZkY, HV_BINOP_MULTIPLY, 1, m, &cBinop_5rzt7ZkY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Rsxbxg70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EyBCiEXy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_iMDSChbX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BDHPdqKS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_fu5UMziG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_z2Y7Sgrx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6f87dewq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Kg1SGLs0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AcnSdfjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_l3tZLj1B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_P9DQPp0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dJtrUIMr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_j7iBnBWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_whgrPFHm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_SJeHSPfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LJKP9nxn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_hCdngQBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yNKj09FS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yNKj09FS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKmbqZiG, HV_BINOP_MULTIPLY, 1, m, &cBinop_DKmbqZiG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DKmbqZiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uzefNFcR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uzefNFcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SJeHSPfu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_0kWKpbLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mIe7e2HK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mIe7e2HK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VE9WYqiS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rzvyoHB4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lnTvNIFJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yTiac90N_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PPzGtieL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FlAzm00X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JCU1G8VB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B1T6AMQs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fQGiRvTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xyaMlTzx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gpbnFl1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K38g28n3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oo4rvqx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6sqzdC3X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5rzt7ZkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0cPCmXpm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_uCO4kXJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Rsxbxg70, 0, m, &cVar_Rsxbxg70_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iRN2BvWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fu5UMziG, 1, m, &cVar_fu5UMziG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yTiac90N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gpbnFl1z, HV_BINOP_MULTIPLY, 0, m, &cBinop_gpbnFl1z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PPzGtieL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fQGiRvTc, HV_BINOP_MULTIPLY, 0, m, &cBinop_fQGiRvTc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lnTvNIFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oo4rvqx0, HV_BINOP_MULTIPLY, 0, m, &cBinop_oo4rvqx0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rzvyoHB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5rzt7ZkY, HV_BINOP_MULTIPLY, 0, m, &cBinop_5rzt7ZkY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FlAzm00X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JCU1G8VB, HV_BINOP_MULTIPLY, 0, m, &cBinop_JCU1G8VB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VE9WYqiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_BDHPdqKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TCacLTiT, 0, m, &cVar_TCacLTiT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EyBCiEXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fu5UMziG, 0, m, &cVar_fu5UMziG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_K7ubwson_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z6aFvI6m, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HjjyzIr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CatRy2GN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IujEmLfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3gychB78, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_uBVA5Eje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r3Rtg0RV, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6rSiWpVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7mjEoZSU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_7mjEoZSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e8pKNZmm, HV_BINOP_DIVIDE, 1, m, &cBinop_e8pKNZmm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1vB8b5dP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_dXwSOiPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_xegRkUf1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_raxMj8Xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_dXwSOiPq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xegRkUf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e8pKNZmm, HV_BINOP_DIVIDE, 0, m, &cBinop_e8pKNZmm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1vB8b5dP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_raxMj8Xf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_e8pKNZmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZeUJwLSM, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZeUJwLSM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZeUJwLSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_53fCARea_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oi7bp3Ju_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_qtZudLfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_spadJVbq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_PZexIuf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HehvD3eP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ztcYapMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_40Df6E3u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_40Df6E3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZeUJwLSM, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZeUJwLSM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BEYp0BKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_sn1uEBEK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sn1uEBEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gR7PHNAX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mooKzYf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zaIc6u0J, HV_BINOP_MULTIPLY, 1, m, &cBinop_zaIc6u0J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9tf6WFVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AXeth0ii, 1, m, &cVar_AXeth0ii_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DMwA3wRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IxfWUucn, HV_BINOP_MULTIPLY, 1, m, &cBinop_IxfWUucn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QBscaLE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_44818zCt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_44818zCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XjgwMogv, HV_BINOP_MULTIPLY, 1, m, &cBinop_XjgwMogv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_AXeth0ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8rKFswsk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_hklrohLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NnH5YZKF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ztcYapMO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KkOxveET_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_VQX33lxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BEYp0BKn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oi7bp3Ju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_PZexIuf7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_53fCARea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qtZudLfm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_spadJVbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qbgvGIyU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_HehvD3eP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pm0A4bHt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_c2OJiwJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3bGXocU6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gR7PHNAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wzZMoihm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wzZMoihm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TQGsyTgb, HV_BINOP_MULTIPLY, 1, m, &cBinop_TQGsyTgb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TQGsyTgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NwrujFZL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NwrujFZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c2OJiwJa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8rKFswsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZrMPmSAc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZrMPmSAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f59oZnWa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0WsaQfhN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1Le1QRyl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xO9a36F7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sYVacgUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K7ubwson_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zaIc6u0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HjjyzIr7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IxfWUucn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IujEmLfg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XjgwMogv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uBVA5Eje_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_EVVLeKZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hklrohLO, 0, m, &cVar_hklrohLO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_begufY4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VQX33lxx, 1, m, &cVar_VQX33lxx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KkOxveET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AXeth0ii, 0, m, &cVar_AXeth0ii_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NnH5YZKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VQX33lxx, 0, m, &cVar_VQX33lxx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0WsaQfhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IxfWUucn, HV_BINOP_MULTIPLY, 0, m, &cBinop_IxfWUucn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_f59oZnWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XjgwMogv, HV_BINOP_MULTIPLY, 0, m, &cBinop_XjgwMogv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xO9a36F7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sYVacgUa, HV_BINOP_MULTIPLY, 0, m, &cBinop_sYVacgUa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1Le1QRyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zaIc6u0J, HV_BINOP_MULTIPLY, 0, m, &cBinop_zaIc6u0J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WDYUdDeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_82ySjFOQ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_qvvrqdnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6q6xJfTA, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_jPCPldJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z8h5v5iK, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hqleUlV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sky1LdAi, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_FgTPxSiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1BDb66NM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yTt8unTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nOYTyeLL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_nOYTyeLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UHIuXrm4, HV_BINOP_DIVIDE, 1, m, &cBinop_UHIuXrm4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cc3RCDLe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_eln6InoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_P7aqJE29_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_D9Cf6L2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_eln6InoJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P7aqJE29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UHIuXrm4, HV_BINOP_DIVIDE, 0, m, &cBinop_UHIuXrm4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Cc3RCDLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D9Cf6L2R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UHIuXrm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bXcEWQos, HV_BINOP_MULTIPLY, 1, m, &cBinop_bXcEWQos_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bXcEWQos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yfFs36jo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wK7kNSVh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_A32HpJ1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8F0767cA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_g0h0nwO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_W9rNFtRL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OlDwU8xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_D8JYOvYF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D8JYOvYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bXcEWQos, HV_BINOP_MULTIPLY, 0, m, &cBinop_bXcEWQos_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hFVWFhAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_jr6wGa8Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jr6wGa8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_swOBmaxn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_05eefwxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KaMKI0ag, HV_BINOP_MULTIPLY, 1, m, &cBinop_KaMKI0ag_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZChKjr2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wSXyere1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wSXyere1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_05eefwxP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yIJrXgAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_t4g4Nfgn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_t4g4Nfgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AnCa5dpF, HV_BINOP_MULTIPLY, 1, m, &cBinop_AnCa5dpF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eyuRjWJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M7TzZxW6, HV_BINOP_MULTIPLY, 1, m, &cBinop_M7TzZxW6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GOJRoewB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZBwTgBlQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZBwTgBlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eyuRjWJx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WvUd0Pvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tk7wbDju, 1, m, &cVar_Tk7wbDju_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Da1iEpYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZWML31dx, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZWML31dx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5qYdb6Qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mlNAs75V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mlNAs75V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ONEeLOnE, HV_BINOP_MULTIPLY, 1, m, &cBinop_ONEeLOnE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Tk7wbDju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XzPuWKU4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_iU20sANk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nAVe9ptg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_OlDwU8xd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UFOrvQDk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_r7Ic28HB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_hFVWFhAC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yfFs36jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_A32HpJ1H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wK7kNSVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_g0h0nwO0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_8F0767cA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0pDGdU8o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_W9rNFtRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_twhqpFpE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_hamC9DdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kVEPs1Nh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_swOBmaxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rIBBD6nb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rIBBD6nb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NxkpoEnF, HV_BINOP_MULTIPLY, 1, m, &cBinop_NxkpoEnF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NxkpoEnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6t0AG64I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6t0AG64I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hamC9DdV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_XzPuWKU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_34k67Sli_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_34k67Sli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_30pcBr7N_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ra6wRi34_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aznOAOPP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w9cHy1C4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fpoFyCJQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7e4sLamJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KaMKI0ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WDYUdDeF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_AnCa5dpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qvvrqdnU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_M7TzZxW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jPCPldJ9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZWML31dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hqleUlV1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ONEeLOnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FgTPxSiP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_DuxTfMna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iU20sANk, 0, m, &cVar_iU20sANk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tyopIQsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r7Ic28HB, 1, m, &cVar_r7Ic28HB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Ra6wRi34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ONEeLOnE, HV_BINOP_MULTIPLY, 0, m, &cBinop_ONEeLOnE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_30pcBr7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_aznOAOPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZWML31dx, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZWML31dx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7e4sLamJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KaMKI0ag, HV_BINOP_MULTIPLY, 0, m, &cBinop_KaMKI0ag_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fpoFyCJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AnCa5dpF, HV_BINOP_MULTIPLY, 0, m, &cBinop_AnCa5dpF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_w9cHy1C4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M7TzZxW6, HV_BINOP_MULTIPLY, 0, m, &cBinop_M7TzZxW6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nAVe9ptg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r7Ic28HB, 0, m, &cVar_r7Ic28HB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UFOrvQDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tk7wbDju, 0, m, &cVar_Tk7wbDju_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NEPFcRDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PWoiz38Z, 1, m, &cIf_PWoiz38Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_LMcOefnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lPWAyAws, m);
}

void Heavy_WSTD_FL3NGR::cBinop_z1yEX9Oy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LMcOefnF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1idFxDJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PWoiz38Z, 0, m, &cIf_PWoiz38Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ebjKyx0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HOLKWDBI, HV_BINOP_DIVIDE, 0, m, &cBinop_HOLKWDBI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_3umFd9U7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KrPGhI5d, HV_BINOP_DIVIDE, 1, m, &cBinop_KrPGhI5d_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HOLKWDBI, HV_BINOP_DIVIDE, 1, m, &cBinop_HOLKWDBI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_k6ECSqAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AoLzyctW, HV_BINOP_DIVIDE, 0, m, &cBinop_AoLzyctW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_e0h9Jb3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AoLzyctW, HV_BINOP_DIVIDE, 1, m, &cBinop_AoLzyctW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Ksg5HBh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KrPGhI5d, HV_BINOP_DIVIDE, 0, m, &cBinop_KrPGhI5d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RD6Bg9d6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ebjKyx0y, 0, m, &cVar_ebjKyx0y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_i6W5l5VH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3umFd9U7, 0, m, &cVar_3umFd9U7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KrPGhI5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_k6ECSqAS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HOLKWDBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_e0h9Jb3S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AoLzyctW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_agI0JFix_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_zqT2uBfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_C1jRRfMP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6981KbbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_UODUDjav_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_agI0JFix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6981KbbU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UODUDjav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_zqT2uBfk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_C1jRRfMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cmIZCmly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_VBwxo2cP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LVUvKWQP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_GtlG1wmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MimprVcY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_YuDNY926_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QWPpqBtw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_toay3Pec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q9Rz4nLn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_HY2BuXad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B90XNSCy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_uNZ24ifZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2XVi09GD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_P6igpHWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mL9OUmw7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_kuJBzgeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vZfDpy2D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_6mjCROqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p3lDv0mG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_nhybzyDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ribBTWT4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_kGnYEtj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2zbC7oYv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_iWvJ3dfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J6KwcbQW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uT8Hco2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9DqSTJG7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9DqSTJG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_AuUBsHAE, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_h4PFxEGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cGN11gH9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_cGN11gH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1aoF7gVN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_rY2Ni6aI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3P2o9xoD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_8eTNGh4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eqfhPt3k_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_w3Ac0I6O, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1aoF7gVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_934Ar2XD, m);
}

void Heavy_WSTD_FL3NGR::cMsg_3P2o9xoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8eTNGh4D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eqfhPt3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nZ6VcltP, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fHSq2tqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Hh2tne0d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Hh2tne0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5hBcuRNr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_3mpFVBkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5cd4PNH7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_nGv1m8tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uRElNOsb_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GmIHzg1W, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5hBcuRNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CYbmWLks, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5cd4PNH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nGv1m8tr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uRElNOsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_x00S5JIi, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vrXrP7m1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_EpozvMRK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EpozvMRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_pPaPn7R5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_TFQIGtD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N0gVswjx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_NTWA6c0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sklQ53kx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pPaPn7R5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qmMgkcOy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qmMgkcOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CFWOxusC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cKiRtewl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CFWOxusC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OR3XSc7g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cKiRtewl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_69zAjoQP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OR3XSc7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vuS74CtC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_69zAjoQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_baOu29iq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_baOu29iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pcvZyrD9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vuS74CtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_TFQIGtD8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pcvZyrD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_NTWA6c0e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cEOwqMNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ijdXoC8W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ijdXoC8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KlY5j9v9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ueZz9eSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RcR9H4gn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_RcR9H4gn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_06QlUfLv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_Nrx9Rhkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Nrx9Rhkl, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_S09pkwOl, 0, m, &cDelay_S09pkwOl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Nrx9Rhkl, 0, m, &cDelay_Nrx9Rhkl_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_zDkO9kqY, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_S09pkwOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_S09pkwOl, m);
  cMsg_mXf3zU1F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_v6z0lnOt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_OapUKtVm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_pFuMiAzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3iIGAdB6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_jnZsI60y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a3k4198y_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Nrx9Rhkl, 2, m, &cDelay_Nrx9Rhkl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ix89w9s9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3iIGAdB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_jnZsI60y, 0, m, &hTable_jnZsI60y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_06QlUfLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_pFuMiAzU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mXf3zU1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_jnZsI60y, 0, m, &hTable_jnZsI60y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ix89w9s9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Nrx9Rhkl, 0, m, &cDelay_Nrx9Rhkl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_a3k4198y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_S09pkwOl, 2, m, &cDelay_S09pkwOl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OapUKtVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_zDkO9kqY, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ZUyzNpsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jFljlFoO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_jFljlFoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_fZgiBZ6Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_tgblDrs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tgblDrs1, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M4fuccsM, 0, m, &cDelay_M4fuccsM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tgblDrs1, 0, m, &cDelay_tgblDrs1_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_sOKHXoyv, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_M4fuccsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M4fuccsM, m);
  cMsg_pEzis8o2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_YlBcxgVx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_j3Ur9yia_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_HxGAvkjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gYqAEiqY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_aHAKQoE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X0xtefSI_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tgblDrs1, 2, m, &cDelay_tgblDrs1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qPSqnscR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gYqAEiqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_aHAKQoE2, 0, m, &hTable_aHAKQoE2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fZgiBZ6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_HxGAvkjm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_pEzis8o2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_aHAKQoE2, 0, m, &hTable_aHAKQoE2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qPSqnscR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tgblDrs1, 0, m, &cDelay_tgblDrs1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_X0xtefSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_M4fuccsM, 2, m, &cDelay_M4fuccsM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_j3Ur9yia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_sOKHXoyv, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_DONRwUuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7pCQXoMC, HV_BINOP_MULTIPLY, 0, m, &cBinop_7pCQXoMC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_A88Bo2RI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wsgRtnAv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_wsgRtnAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lgC7UFib_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7pCQXoMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1mRrjUun_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uiMgcgOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7pCQXoMC, HV_BINOP_MULTIPLY, 1, m, &cBinop_7pCQXoMC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lgC7UFib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uiMgcgOH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1mRrjUun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZXnnMdCr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZXnnMdCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BzIA3W7H_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YyI2gZZF, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BzIA3W7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zQYeIUJM, m);
}

void Heavy_WSTD_FL3NGR::cVar_spvGxTZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bG4iPpd0, HV_BINOP_MULTIPLY, 0, m, &cBinop_bG4iPpd0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_k0IL8Ujr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_D8MFj1t2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_D8MFj1t2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pLZ8VZvi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bG4iPpd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_oGjqx5Db_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_r6gYefOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bG4iPpd0, HV_BINOP_MULTIPLY, 1, m, &cBinop_bG4iPpd0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_pLZ8VZvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_r6gYefOT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oGjqx5Db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3GHv1NPo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3GHv1NPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_T3zkSNI6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_IguPLy0M, m);
}

void Heavy_WSTD_FL3NGR::cBinop_T3zkSNI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2hgeWFTa, m);
}

void Heavy_WSTD_FL3NGR::cMsg_KlY5j9v9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Oic3g2ju, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_sB7NSa22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_WdAIC96f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0O97Dbj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_sB7NSa22_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_s9PNcGlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TQXEoeJ0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yWEwjlX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uLuh6Cp0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uLuh6Cp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fkgrvBq4, HV_BINOP_MULTIPLY, 1, m, &cBinop_fkgrvBq4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TQXEoeJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_yWEwjlX3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fkgrvBq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HGFFnSX4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WdAIC96f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fkgrvBq4, HV_BINOP_MULTIPLY, 0, m, &cBinop_fkgrvBq4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HGFFnSX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I1JjPUFG, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_o8nnXQA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_RTGmZHcw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RTGmZHcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s9PNcGlY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0O97Dbj9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_8MfCB5x1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YqBW7xPm, 0, m, &cSlice_YqBW7xPm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EhBJDmGf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_YqBW7xPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_uRaD7Cdt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_uRaD7Cdt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_wwoqu8Ek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uRaD7Cdt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_uRaD7Cdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kCn7eYEX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_EhBJDmGf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7fPxJjyy, 0, m, &cSlice_7fPxJjyy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pnoxLxfD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_7fPxJjyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WrYiFLf7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WrYiFLf7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_CvSMFJ2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WrYiFLf7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_WrYiFLf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qBmm7jG4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_pnoxLxfD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PpA9Y4Vh, 0, m, &cSlice_PpA9Y4Vh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cRGKDTjG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_PpA9Y4Vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0yPmFsKe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0yPmFsKe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_C7dIQyVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0yPmFsKe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_0yPmFsKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6VQxa9CL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_cRGKDTjG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dQmcmQ8z, 0, m, &cSlice_dQmcmQ8z_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_dQmcmQ8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BjB61t1P_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BjB61t1P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_gvQ3PsoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BjB61t1P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_BjB61t1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xQYIshNO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_N0gVswjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HDsWzSeF, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_sklQ53kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q4iQCEwb, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_tVatXqXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ViaaQ3fj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ViaaQ3fj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_3VmzEI9f, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_LyMtyGAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_K1S1GTM9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_K1S1GTM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nJUhpxz5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_360yI5Sa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IAjbIbFl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_oWdmzvXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_X2bceI0P_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ik8TzPwN, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nJUhpxz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uhAuy5yH, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IAjbIbFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oWdmzvXA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_X2bceI0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uc0CnL8k, m);
}

void Heavy_WSTD_FL3NGR::cMsg_7f3uSCqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JxmX3E04_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_JxmX3E04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3QOrTX0u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_jQpJqLNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7X2r6acd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_9RA3tNAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OkvwKmEa_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_sMxWsk9O, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3QOrTX0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_AT6KK8dy, m);
}

void Heavy_WSTD_FL3NGR::cMsg_7X2r6acd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9RA3tNAJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OkvwKmEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Xyz9qgpd, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SR5DJ1zT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GmEWLtoB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GmEWLtoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_TW7rUrKY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_shpDPqlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jZ2qUoGQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_QU5RlEAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ihnnlXHS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TW7rUrKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qEws4KyN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qEws4KyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MXnSWE5l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e2dmgdYP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MXnSWE5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IpKOfeMW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_e2dmgdYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AceAYrIH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IpKOfeMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_z3Oodt40_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_AceAYrIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xFd2t7vW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xFd2t7vW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KDnItXXH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z3Oodt40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_shpDPqlM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KDnItXXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_QU5RlEAP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aOw5cwVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_36pqWTrh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_36pqWTrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nHXjcJXo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_5oI8EuVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ka2fnEkk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Ka2fnEkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_PWBHAnJF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_t3eaQqYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_t3eaQqYi, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_87krexGQ, 0, m, &cDelay_87krexGQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_t3eaQqYi, 0, m, &cDelay_t3eaQqYi_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IBjTHYbx, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_87krexGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_87krexGQ, m);
  cMsg_kjyHczmT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_srkue6E1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_EWRSBeYm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_oY7NNJ5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c3Nv7wrP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_T3T3Uyfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MlfTdwYn_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_t3eaQqYi, 2, m, &cDelay_t3eaQqYi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hj4mB8W7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_c3Nv7wrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_T3T3Uyfm, 0, m, &hTable_T3T3Uyfm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PWBHAnJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_oY7NNJ5e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kjyHczmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_T3T3Uyfm, 0, m, &hTable_T3T3Uyfm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Hj4mB8W7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_t3eaQqYi, 0, m, &cDelay_t3eaQqYi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MlfTdwYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_87krexGQ, 2, m, &cDelay_87krexGQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EWRSBeYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IBjTHYbx, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_okRCqrnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_k7TQp8FX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_k7TQp8FX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vYzBnFnv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_1hFaqHyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1hFaqHyt, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O55kkzCp, 0, m, &cDelay_O55kkzCp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1hFaqHyt, 0, m, &cDelay_1hFaqHyt_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LSIxTiW1, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_O55kkzCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_O55kkzCp, m);
  cMsg_tdO4013k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_5tvCHHie_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_pCGTodNG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_fIHZy5lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y14PpmHd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_ob9XAt1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w7GpEH8S_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1hFaqHyt, 2, m, &cDelay_1hFaqHyt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TzAvk10l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_y14PpmHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ob9XAt1H, 0, m, &hTable_ob9XAt1H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vYzBnFnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_fIHZy5lb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tdO4013k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ob9XAt1H, 0, m, &hTable_ob9XAt1H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TzAvk10l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1hFaqHyt, 0, m, &cDelay_1hFaqHyt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_w7GpEH8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_O55kkzCp, 2, m, &cDelay_O55kkzCp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_pCGTodNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LSIxTiW1, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_g6z9RGgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xSvVmZbn, HV_BINOP_MULTIPLY, 0, m, &cBinop_xSvVmZbn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dvD6nAO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jy7kYdM7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_jy7kYdM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P4FqmLTv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xSvVmZbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ViesYbOt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WAQ6QdyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xSvVmZbn, HV_BINOP_MULTIPLY, 1, m, &cBinop_xSvVmZbn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_P4FqmLTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WAQ6QdyM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ViesYbOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_CAbV71GE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CAbV71GE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_WeLqkzSP_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_X3F7zLgQ, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WeLqkzSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3i3pakgZ, m);
}

void Heavy_WSTD_FL3NGR::cVar_nWOuTNmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LhNEZ7KR, HV_BINOP_MULTIPLY, 0, m, &cBinop_LhNEZ7KR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oeraKfpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cvojGSmB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_cvojGSmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RYRXnZ3W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LhNEZ7KR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_H8hYvy8W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iDp1yHEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LhNEZ7KR, HV_BINOP_MULTIPLY, 1, m, &cBinop_LhNEZ7KR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_RYRXnZ3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iDp1yHEm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_H8hYvy8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wi6VTe2Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wi6VTe2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_82xdWolY_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1DWs3hhB, m);
}

void Heavy_WSTD_FL3NGR::cBinop_82xdWolY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0PyQMCF1, m);
}

void Heavy_WSTD_FL3NGR::cMsg_nHXjcJXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KXTSOAx3, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_Qefk8X3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_KeZhgUa3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iDdpZsYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dRI1xRC3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qbzXzxhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_Qefk8X3n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_thaV3y0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GzNGloAC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GzNGloAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xJQDAZI7, HV_BINOP_MULTIPLY, 1, m, &cBinop_xJQDAZI7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dRI1xRC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_thaV3y0g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xJQDAZI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6aM99YaE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KeZhgUa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xJQDAZI7, HV_BINOP_MULTIPLY, 0, m, &cBinop_xJQDAZI7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6aM99YaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_56nQiYn4, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_TG9Idn9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_qKMeW53t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qKMeW53t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iDdpZsYM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qbzXzxhD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_hi0APqFJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qtGZFDe0, 0, m, &cSlice_qtGZFDe0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Rrdt1Nio_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_qtGZFDe0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rpLdjT9c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rpLdjT9c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_X9ufwYLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rpLdjT9c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_rpLdjT9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LTOuWRNh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Rrdt1Nio_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EalRrZWG, 0, m, &cSlice_EalRrZWG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_592xJTfY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_EalRrZWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Yt0qNbJG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Yt0qNbJG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_GOuzTRfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Yt0qNbJG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Yt0qNbJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_baDp2gRe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_592xJTfY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_v0M7akzD, 0, m, &cSlice_v0M7akzD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lYLQHvBR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_v0M7akzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_T0PTVH2E_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_T0PTVH2E_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ngELj3Po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T0PTVH2E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_T0PTVH2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7mwLs9Xw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_lYLQHvBR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GXFqSbHx, 0, m, &cSlice_GXFqSbHx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_GXFqSbHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xXl3x3FZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xXl3x3FZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_B0Z0uRxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xXl3x3FZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xXl3x3FZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vCxRgtEr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jZ2qUoGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jTyLFTYT, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ihnnlXHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NMGiU4Ja, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_KO3ywMBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_WM0dzlH4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WM0dzlH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_7wMWvrc2, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_2cIBEr0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PX9m5boE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_PX9m5boE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NHpad29u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_CIKQAU3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cOkeDa5l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_APUril5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NMv2j1aM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XsKCuS5Z, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NHpad29u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6pdHMJ1x, m);
}

void Heavy_WSTD_FL3NGR::cMsg_cOkeDa5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_APUril5U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NMv2j1aM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qJb5nb1I, m);
}

void Heavy_WSTD_FL3NGR::cMsg_OIt2bK6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aV7X8pXp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_aV7X8pXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qCG0psNa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_5DO2Y6xA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DYGYV2Ok_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_nHtdP5q7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PRGMBKbN_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dBDD2B7N, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qCG0psNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0FEBFhts, m);
}

void Heavy_WSTD_FL3NGR::cMsg_DYGYV2Ok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nHtdP5q7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PRGMBKbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_phgIFGG5, m);
}

void Heavy_WSTD_FL3NGR::cBinop_edItg4VK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_uLXZLf6L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uLXZLf6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_YuKWRicr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_OD7cVSeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1AjONxFT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_OuZbG8Gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pc0yoivB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YuKWRicr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_t3kElLZc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_t3kElLZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wh9nRjW7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CqqxAs8f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CqqxAs8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cqnGcqVt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Wh9nRjW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2xeJ5CyQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2xeJ5CyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YjWFRCUy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cqnGcqVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1lGtQvVc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1lGtQvVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_effpgP3X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YjWFRCUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_OD7cVSeZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_effpgP3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_OuZbG8Gv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_p1DXceOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_niC1jjOb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_niC1jjOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7WbcqTKs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8WJ5vzXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yxelqOTx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_yxelqOTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4CiwcJxN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_x3aTmfk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_x3aTmfk2, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xYomTTP5, 0, m, &cDelay_xYomTTP5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_x3aTmfk2, 0, m, &cDelay_x3aTmfk2_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_J58SQrMi, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_xYomTTP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xYomTTP5, m);
  cMsg_43DYMjlV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_48zsBPES_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wb8LMcAj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_bxZ78xfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CvlPiPlE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_nRN7JZHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hPjwpX2d_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_x3aTmfk2, 2, m, &cDelay_x3aTmfk2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gH48gcoD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CvlPiPlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_nRN7JZHi, 0, m, &hTable_nRN7JZHi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4CiwcJxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_bxZ78xfT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_43DYMjlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_nRN7JZHi, 0, m, &hTable_nRN7JZHi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gH48gcoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_x3aTmfk2, 0, m, &cDelay_x3aTmfk2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hPjwpX2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xYomTTP5, 2, m, &cDelay_xYomTTP5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wb8LMcAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_J58SQrMi, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_jIG0EqaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Sw2d0T9f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Sw2d0T9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VyFC1MuZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_93F2wLzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_93F2wLzF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mDolioFR, 0, m, &cDelay_mDolioFR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_93F2wLzF, 0, m, &cDelay_93F2wLzF_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EUOScsc5, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_mDolioFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mDolioFR, m);
  cMsg_2JbSJ3lN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_wjmqoQKR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_f4aeqcL2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_FBqbIuoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rol45f56_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_WHfFeRML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wvdoXldn_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_93F2wLzF, 2, m, &cDelay_93F2wLzF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JGePYeA9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rol45f56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_WHfFeRML, 0, m, &hTable_WHfFeRML_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VyFC1MuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_FBqbIuoO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2JbSJ3lN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_WHfFeRML, 0, m, &hTable_WHfFeRML_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JGePYeA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_93F2wLzF, 0, m, &cDelay_93F2wLzF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wvdoXldn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_mDolioFR, 2, m, &cDelay_mDolioFR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_f4aeqcL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EUOScsc5, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_4N0XHdA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HybtfPFH, HV_BINOP_MULTIPLY, 0, m, &cBinop_HybtfPFH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6GEjwHyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_D2C6nTk1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_D2C6nTk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6MDqIQz8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HybtfPFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rFUbdd1t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_C9c8GUq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HybtfPFH, HV_BINOP_MULTIPLY, 1, m, &cBinop_HybtfPFH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6MDqIQz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_C9c8GUq9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rFUbdd1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_38smNmKc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_38smNmKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_u2jyfwkP_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iNpA9lGy, m);
}

void Heavy_WSTD_FL3NGR::cBinop_u2jyfwkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VfIuVmZb, m);
}

void Heavy_WSTD_FL3NGR::cVar_NllfuXb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HNSpxT6J, HV_BINOP_MULTIPLY, 0, m, &cBinop_HNSpxT6J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wicDn6ys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mVdszfHv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_mVdszfHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iRF7S9aa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HNSpxT6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Yb5oumSd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TBpbCxLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HNSpxT6J, HV_BINOP_MULTIPLY, 1, m, &cBinop_HNSpxT6J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_iRF7S9aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TBpbCxLI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Yb5oumSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_uhDx7FLg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uhDx7FLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_KJBGg3lk_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gur3ZBXM, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KJBGg3lk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_IFfd8ufL, m);
}

void Heavy_WSTD_FL3NGR::cMsg_7WbcqTKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6wXrpXjk, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_KZ8r1dM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_pZeP3Xeo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_O61Zhtdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_KZ8r1dM9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Zr0iWY1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xbRcaKos_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YBcIrylV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_4lyUhV9F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4lyUhV9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tfbw0NDJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Tfbw0NDJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xbRcaKos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_YBcIrylV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Tfbw0NDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vGDz7yeQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pZeP3Xeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tfbw0NDJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Tfbw0NDJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vGDz7yeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ukNAW7H6, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_HrJe0vlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_Bkm1NeKx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Bkm1NeKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zr0iWY1R_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O61Zhtdu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_iYgvWEfe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gmECyTW7, 0, m, &cSlice_gmECyTW7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2p8Jfwfb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_gmECyTW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_i8hiDkkI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_i8hiDkkI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_spswMe3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i8hiDkkI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_i8hiDkkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ohd0Jy8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2p8Jfwfb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sIbekN4R, 0, m, &cSlice_sIbekN4R_sendMessage);
      break;
    }
    default: {
      cSwitchcase_v5W4Io5J_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_sIbekN4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8Jg7euWi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8Jg7euWi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_qm8x6zut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8Jg7euWi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_8Jg7euWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IrlRO4VM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_v5W4Io5J_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5dBSkdHm, 0, m, &cSlice_5dBSkdHm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uM8ZoKQC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_5dBSkdHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Pi9oaWEe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Pi9oaWEe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_qkgQIIkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Pi9oaWEe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Pi9oaWEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7igK9azj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_uM8ZoKQC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_iYtuupQD, 0, m, &cSlice_iYtuupQD_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_iYtuupQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jmFFveDW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jmFFveDW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_KGPzC9gR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jmFFveDW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_jmFFveDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mPwRYsnd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1AjONxFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LMeC5Dp0, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_pc0yoivB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ivwY06UJ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_PZqTUYXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DJQK5dKY_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zWY2mRgV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_BRd4kknL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DJQK5dKY_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zWY2mRgV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_SzHokyVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DJQK5dKY_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zWY2mRgV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_nPQgh4ZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DJQK5dKY_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zWY2mRgV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_cmIZCmly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DJQK5dKY_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zWY2mRgV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ODIGiJsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_LoW9HGrd, 0, m, &cVar_LoW9HGrd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kU6jHDkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_fqlbZsmk, 0, m, &cVar_fqlbZsmk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7EAIwm9u, 0, m, &cVar_7EAIwm9u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cy1LoYEz, 0, m, &cVar_cy1LoYEz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_q9Rz4nLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8MfCB5x1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LVUvKWQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8MfCB5x1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MimprVcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8MfCB5x1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QWPpqBtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8MfCB5x1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_UQLZ3m7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_toay3Pec, 0, m, &cVar_toay3Pec_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kwXY7AOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VBwxo2cP, 0, m, &cVar_VBwxo2cP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Xs0axXib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YuDNY926, 0, m, &cVar_YuDNY926_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vZfDpy2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hi0APqFJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_B90XNSCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hi0APqFJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2XVi09GD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hi0APqFJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mL9OUmw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hi0APqFJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_WTz1QB3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kuJBzgeG, 0, m, &cVar_kuJBzgeG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vV9cFNq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HY2BuXad, 0, m, &cVar_HY2BuXad_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l8JOIQfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P6igpHWH, 0, m, &cVar_P6igpHWH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_J6KwcbQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iYgvWEfe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_p3lDv0mG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iYgvWEfe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ribBTWT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iYgvWEfe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2zbC7oYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_iYgvWEfe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_nR6siNV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iWvJ3dfq, 0, m, &cVar_iWvJ3dfq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x20Gd9H6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6mjCROqc, 0, m, &cVar_6mjCROqc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_J6wx3ToJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kGnYEtj0, 0, m, &cVar_kGnYEtj0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_iyCCkqsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fqlbZsmk, 0, m, &cVar_fqlbZsmk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bRrQJ9wQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7EAIwm9u, 0, m, &cVar_7EAIwm9u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_JNBCndHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cy1LoYEz, 0, m, &cVar_cy1LoYEz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6eOwjrO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kVcRnUnt, 0, m, &cVar_kVcRnUnt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_4910ls9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5HqIM7Yl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2mDj92PR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_lTRdEPJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2A8DkVbt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LNt4fu9U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j5N3EClS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_EIpUk3gU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aY3hEFHD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cDj4YD3Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_14aVFDbx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6eWr1Qxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a0gTVFyB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TaTWyRNy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FCdKrxwx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SEyRRcOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dy0OTsQ4_sendMessage(_c, 0, m);
  cMsg_GgrGNRpG_sendMessage(_c, 0, m);
  cMsg_Ld8UoYTe_sendMessage(_c, 0, m);
  cMsg_dMMx60uQ_sendMessage(_c, 0, m);
  cMsg_6rSiWpVA_sendMessage(_c, 0, m);
  cMsg_yTt8unTV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_E96fJQ3Y, 0, m, &cVar_E96fJQ3Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kVcRnUnt, 0, m, &cVar_kVcRnUnt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_csUuJxOR, 0, m, &cVar_csUuJxOR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Rsxbxg70, 0, m, &cVar_Rsxbxg70_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hklrohLO, 0, m, &cVar_hklrohLO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iU20sANk, 0, m, &cVar_iU20sANk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UGCOqc8F, 0, m, &cVar_UGCOqc8F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_J61wQ1d8, 0, m, &cVar_J61wQ1d8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_akYTqPxL, 0, m, &cVar_akYTqPxL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hm4Ljawj, 0, m, &cVar_hm4Ljawj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5dTwTVBF, 0, m, &cVar_5dTwTVBF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aiUIZYm4, 0, m, &cVar_aiUIZYm4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8EBCAkRx, 0, m, &cVar_8EBCAkRx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0CJfr7D7, 0, m, &cVar_0CJfr7D7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MXhkHKzD, 0, m, &cVar_MXhkHKzD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FzMnO1gj, 0, m, &cVar_FzMnO1gj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hAsCb00g, 0, m, &cVar_hAsCb00g_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QtQLCsax, 0, m, &cVar_QtQLCsax_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PHHGBeU3, 0, m, &cVar_PHHGBeU3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Fl2uB7TG, 0, m, &cVar_Fl2uB7TG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qAvo5lCq, 0, m, &cVar_qAvo5lCq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LLkZVMZp, 0, m, &cVar_LLkZVMZp_sendMessage);
  cMsg_A88Bo2RI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DONRwUuD, 0, m, &cVar_DONRwUuD_sendMessage);
  cMsg_k0IL8Ujr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_spvGxTZp, 0, m, &cVar_spvGxTZp_sendMessage);
  cMsg_dvD6nAO3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_g6z9RGgO, 0, m, &cVar_g6z9RGgO_sendMessage);
  cMsg_oeraKfpX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nWOuTNmN, 0, m, &cVar_nWOuTNmN_sendMessage);
  cMsg_6GEjwHyY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4N0XHdA4, 0, m, &cVar_4N0XHdA4_sendMessage);
  cMsg_wicDn6ys_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NllfuXb0, 0, m, &cVar_NllfuXb0_sendMessage);
  cMsg_ueZz9eSe_sendMessage(_c, 0, m);
  cMsg_ZUyzNpsz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wwoqu8Ek, 0, m, &cVar_wwoqu8Ek_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CvSMFJ2D, 0, m, &cVar_CvSMFJ2D_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C7dIQyVo, 0, m, &cVar_C7dIQyVo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gvQ3PsoN, 0, m, &cVar_gvQ3PsoN_sendMessage);
  cMsg_5oI8EuVZ_sendMessage(_c, 0, m);
  cMsg_okRCqrnJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_X9ufwYLs, 0, m, &cVar_X9ufwYLs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GOuzTRfY, 0, m, &cVar_GOuzTRfY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ngELj3Po, 0, m, &cVar_ngELj3Po_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_B0Z0uRxu, 0, m, &cVar_B0Z0uRxu_sendMessage);
  cMsg_8WJ5vzXC_sendMessage(_c, 0, m);
  cMsg_jIG0EqaQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_spswMe3Y, 0, m, &cVar_spswMe3Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qm8x6zut, 0, m, &cVar_qm8x6zut_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qkgQIIkS, 0, m, &cVar_qkgQIIkS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KGPzC9gR, 0, m, &cVar_KGPzC9gR_sendMessage);
  cMsg_kU6jHDkV_sendMessage(_c, 0, m);
  cMsg_ODIGiJsW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rY2Ni6aI, 0, m, &cVar_rY2Ni6aI_sendMessage);
  cMsg_h4PFxEGC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3mpFVBkQ, 0, m, &cVar_3mpFVBkQ_sendMessage);
  cMsg_fHSq2tqx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_360yI5Sa, 0, m, &cVar_360yI5Sa_sendMessage);
  cMsg_LyMtyGAH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jQpJqLNV, 0, m, &cVar_jQpJqLNV_sendMessage);
  cMsg_7f3uSCqi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CIKQAU3i, 0, m, &cVar_CIKQAU3i_sendMessage);
  cMsg_2cIBEr0Z_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5DO2Y6xA, 0, m, &cVar_5DO2Y6xA_sendMessage);
  cMsg_OIt2bK6G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_bTiTytwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oLA8Y5p5, HV_BINOP_MULTIPLY, 0, m, &cBinop_oLA8Y5p5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_paC1cnF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1LB2SQKo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3XFxFht4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mUfkI0tE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_KWejCt2U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_KDUapOMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_L7sM47kw_sendMessage);
  cMsg_2rr8KVfE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_y4v4IJdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cCnTeb9J, HV_BINOP_MULTIPLY, 0, m, &cBinop_cCnTeb9J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Q5MxoafW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_iJCrRsZu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_NDgOpgWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DzvdJxRX, HV_BINOP_MULTIPLY, 1, m, &cBinop_DzvdJxRX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DADF5uyI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iwywSNiy_sendMessage);
  cMsg_fGbz2oEQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_wx7G1p2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a0O1bQdv, HV_BINOP_MULTIPLY, 0, m, &cBinop_a0O1bQdv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_KpRjkZsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kUmcF0AD_sendMessage(_c, 0, m);
  cMsg_XmUwH90X_sendMessage(_c, 0, m);
  cMsg_4rN4xdko_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_8QODElVu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7N3Vx8BF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Jw3n6P4N_sendMessage);
  cMsg_aKNoirTf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_B01AM6Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hklrohLO, 0, m, &cVar_hklrohLO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SN4WIcqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_begufY4i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EVVLeKZV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_RAj5aiC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Of527Xp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_33v665em_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Uo6QREnI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_39pu3fFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5lcZDQJV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UeixTajd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EFE2tU7a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XPp4P5aQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0y2jNbZs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WRTWF2mN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_45QFIhgi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_dJtrUIMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKmbqZiG, HV_BINOP_MULTIPLY, 0, m, &cBinop_DKmbqZiG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_whgrPFHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qQjwEyqw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YhhgBQXa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KsFwobxb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_PAYiRGzA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LJKP9nxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4yUM5a5g_sendMessage);
  cMsg_usrKX4pR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_qbgvGIyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TQGsyTgb, HV_BINOP_MULTIPLY, 0, m, &cBinop_TQGsyTgb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_pm0A4bHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_DMwA3wRA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3bGXocU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sYVacgUa, HV_BINOP_MULTIPLY, 1, m, &cBinop_sYVacgUa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mooKzYf0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9tf6WFVv_sendMessage);
  cMsg_QBscaLE0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_0pDGdU8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NxkpoEnF, HV_BINOP_MULTIPLY, 0, m, &cBinop_NxkpoEnF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_twhqpFpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZChKjr2h_sendMessage(_c, 0, m);
  cMsg_yIJrXgAh_sendMessage(_c, 0, m);
  cMsg_GOJRoewB_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Da1iEpYZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_kVEPs1Nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WvUd0Pvj_sendMessage);
  cMsg_5qYdb6Qg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_qCHNB9eh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LoW9HGrd, 0, m, &cVar_LoW9HGrd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_O3FoI75s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_UQLZ3m7n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_sca2YuuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_kwXY7AOW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Zr55k2k3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GtlG1wmK, 0, m, &cVar_GtlG1wmK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_nK3PzB8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Xs0axXib_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9TZA1ipO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_WTz1QB3z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_IXflUxJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_vV9cFNq6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fDG2IbFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uNZ24ifZ, 0, m, &cVar_uNZ24ifZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_eUtxsJFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_l8JOIQfw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Omo8v3t3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nR6siNV1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SUBhYq2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_x20Gd9H6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7GwN5yNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nhybzyDZ, 0, m, &cVar_nhybzyDZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_nQyhFVE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_J6wx3ToJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6VQxa9CL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_uT8Hco2O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qBmm7jG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_o8nnXQA1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xQYIshNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vrXrP7m1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_kCn7eYEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cEOwqMNP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7mwLs9Xw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_tVatXqXp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_baDp2gRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_TG9Idn9q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vCxRgtEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SR5DJ1zT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LTOuWRNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_aOw5cwVJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7igK9azj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_KO3ywMBQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_IrlRO4VM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_HrJe0vlt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_mPwRYsnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_edItg4VK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Ohd0Jy8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_p1DXceOj_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_3b5Lb9kK, VOf(Bf0));
    __hv_line_f(&sLine_5pdRwlUq, VOf(Bf1));
    __hv_line_f(&sLine_l70MpCB8, VOf(Bf2));
    __hv_line_f(&sLine_0Xj2bOwj, VOf(Bf3));
    __hv_line_f(&sLine_uies1ql3, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_YaWOQuBW, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_rCf65dAC, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_4ssQJkHF, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_opJ0aZvt, VOf(Bf1));
    __hv_line_f(&sLine_FCx1jg80, VOf(Bf0));
    __hv_line_f(&sLine_wHT95bmE, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_SWmEBlcg, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_eEKIcJ0M, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_11sNIWlK, VOf(Bf5));
    __hv_line_f(&sLine_t75ki2MV, VOf(Bf1));
    __hv_line_f(&sLine_Zb6YUBu5, VOf(Bf2));
    __hv_line_f(&sLine_VEq3rhW4, VOf(Bf4));
    __hv_line_f(&sLine_76njA3SW, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_tsdo2Khx, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_EvVZSuUF, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_WERGYbFl, VOf(Bf6));
    __hv_line_f(&sLine_uNxrLsaW, VOf(Bf2));
    __hv_line_f(&sLine_CGvrdPyX, VOf(Bf1));
    __hv_line_f(&sLine_DrdgR2fq, VOf(Bf5));
    __hv_line_f(&sLine_2mtPhHh7, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_p2ZsENeT, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_m6yyeqmq, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_z6aFvI6m, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_CatRy2GN, VOf(Bf2));
    __hv_line_f(&sLine_3gychB78, VOf(Bf6));
    __hv_line_f(&sLine_r3Rtg0RV, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_smsBpBR8, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_lPWAyAws, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_82ySjFOQ, VOf(Bf8));
    __hv_line_f(&sLine_6q6xJfTA, VOf(Bf2));
    __hv_line_f(&sLine_z8h5v5iK, VOf(Bf1));
    __hv_line_f(&sLine_Sky1LdAi, VOf(Bf7));
    __hv_line_f(&sLine_1BDb66NM, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_9ovstBVP, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_kWfAjVAj, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_q4iQCEwb, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_AuUBsHAE, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_Oic3g2ju, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_YyI2gZZF, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_zQYeIUJM, VOf(Bf8));
    __hv_rpole_f(&sRPole_hLFhXDnd, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_IguPLy0M, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_2hgeWFTa, VOf(Bf10));
    __hv_rpole_f(&sRPole_6yJQjDNu, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_yZto2JCT, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_934Ar2XD, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_nZ6VcltP, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_w3Ac0I6O, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_LMCaSiw2, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_jZzOrFQ1, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_HDsWzSeF, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_OEU966Tx, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_CYbmWLks, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_x00S5JIi, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_GmIHzg1W, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_7CTvnIy0, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_OQEHgfQ1, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_I1JjPUFG, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_zDkO9kqY, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_sOKHXoyv, VIf(Bf3));
    __hv_varwrite_f(&sVarf_npEVCbwm, VIf(Bf11));
    __hv_line_f(&sLine_NMGiU4Ja, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_3VmzEI9f, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_KXTSOAx3, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_X3F7zLgQ, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_3i3pakgZ, VOf(Bf10));
    __hv_rpole_f(&sRPole_9tUCt1rG, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_1DWs3hhB, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_0PyQMCF1, VOf(Bf5));
    __hv_rpole_f(&sRPole_4F4RJ45g, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_L1egLcQf, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_uhAuy5yH, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_uc0CnL8k, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_ik8TzPwN, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_DThH8iIp, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_uOY2JMAB, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_jTyLFTYT, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_KVxCPjdt, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_AT6KK8dy, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_Xyz9qgpd, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_sMxWsk9O, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_ngbsxazB, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_guD2wAKC, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_56nQiYn4, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_IBjTHYbx, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_LSIxTiW1, VIf(Bf0));
    __hv_varwrite_f(&sVarf_UTkAm23H, VIf(Bf8));
    __hv_line_f(&sLine_ivwY06UJ, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_7wMWvrc2, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_6wXrpXjk, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_iNpA9lGy, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_VfIuVmZb, VOf(Bf5));
    __hv_rpole_f(&sRPole_iqlvj3ix, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_gur3ZBXM, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_IFfd8ufL, VOf(Bf6));
    __hv_rpole_f(&sRPole_74BK7t5B, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_YXN8xdBt, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_6pdHMJ1x, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_qJb5nb1I, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_XsKCuS5Z, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_sgdUqCFz, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_iDT5GGTH, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_LMeC5Dp0, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_kzjcmKgs, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_0FEBFhts, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_phgIFGG5, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_dBDD2B7N, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_gKHK20YU, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_9uJPz5Jm, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_ukNAW7H6, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_J58SQrMi, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_EUOScsc5, VIf(Bf4));
    __hv_varwrite_f(&sVarf_0P97rpXv, VIf(Bf10));
    __hv_varwrite_f(&sVarf_9kvRD8qS, VIf(Bf2));
    __hv_varwrite_f(&sVarf_6lE6kiqn, VIf(Bf9));
    __hv_varwrite_f(&sVarf_A6ImbY59, VIf(Bf11));
    __hv_varread_f(&sVarf_npEVCbwm, VOf(Bf11));
    __hv_varread_f(&sVarf_UTkAm23H, VOf(Bf9));
    __hv_varread_f(&sVarf_0P97rpXv, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_9kvRD8qS, VOf(Bf2));
    __hv_varread_f(&sVarf_6lE6kiqn, VOf(Bf11));
    __hv_varread_f(&sVarf_A6ImbY59, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
